# An example of the review

Writing lists are not recommended for reviews. The better choice is to use table as an alternative.

| Num |     | Positive review        |
| :-- | :-: | :--------------------- |
| ①   | ➕  | Good **game** design.  |
| ②   | ➕  | Good _music_.          |
| ③   | ➕  | Good <ins>story</ins>. |

| Num |     | Negative review  |
| :-- | :-: | :--------------- |
| ①   | ➖  | Bad art.         |
| ②   | ➖  | No localization. |
| ③   | ➖  | High price.      |

# Point 1: Game design

> A game design is always important.

The game's good design makes me recall the experience in Hollow Knight.

https://store.steampowered.com/app/367520/Hollow_Knight/

# Point 2: Good music

Recommend users to find more details in the following website:

[OST of the game][link-ost]

# Point 3: Good story

> The following part may contain **Spoilers**!

The story contains some ==special information==.

==Well, I would like to use a full paragraph to discuss this.==

How about a very long spoiler block?

> I am a cite block with an author name!
>
> <cite>John Smith</cite>
>
> More cite tags will be rendered as plain text.
>
> <cite>John Smith II</cite>

> [!CAUTION]
> I am spoiler block.
>
> I have several lines.
>
> #### Even I am a title, I will still be inside the block.

> [!caution]
> The block title is case insensitive.

> [!tag_b]
> This is not a standard alert format. Will it work?
>
> #### A strange title
>
> > Quote in bold env?

> [!tag_spoiler]
> A spoiler block can be created in such non-standard format.

[link-ost]: https://open.spotify.com/album/4XgGOMRY7H4hl6OQi5wb2Z
